#!/usr/bin/env python
from __future__ import with_statement
import os
from pygments import highlight
from pygments.lexers import get_lexer_by_name
from pygments.formatters import HtmlFormatter

files_to_highlight = [
    ('unittest',
     ('tests_unittest/test_foo.py',
      'tests_unittest/__init__.py',
      'run-unittest.py',
      'setup-unittest.py'),
    ),
    ('pytest',
     ('tests_pytest/test_foo.py',
      'tests_pytest/test_class_foo.py',
      'tests_pytest/test_importorskip.py',
      'tests_pytest/test_skip.py',
      'tests_pytest/test_db_with_setup_module.py',
      'tests_pytest/example-conftest.py',)
    ),
    ('nose',
     ('tests_nose/test_foo.py',
      'tests_nose/test_class_foo.py',
      'tests_nose/test_skip.py',)
    ),
]


import shutil
try:
    shutil.rmtree('html')
except:
    pass


os.mkdir('html')


# Create the css style sheet, so we can add our own stuff to it
os.system('pygmentize -S colorful -f html > html/code.css')
with open('html/code.css', 'ab') as f:
    f.write('pre { font: 24px Monaco, Andale Mono, Courier New, monospace; }\n')


lexer = get_lexer_by_name("python", stripall=True)
formatter = HtmlFormatter()


def get_code(lexer, formatter, filename):
    f = open(filename, 'rb')
    code = f.read()
    f.close()

    return highlight(code, lexer, formatter)


for dir, files in files_to_highlight:
    outdir = 'html/' + dir
    
    try:
        os.mkdir(outdir)
    except OSError, e:
        if e.errno != 17:
            raise
    
    for path in files:
        basename = os.path.basename(path)
        outfile = outdir + '/' + os.path.splitext(basename)[0] + '.html'

        formatted_code = get_code(lexer, formatter, path)

        with open(outfile, 'wb') as f:
            f.write('''<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"
               "http://www.w3.org/TR/html4/strict.dtd">
<html>
    <head>
        <link rel="stylesheet" href="../code.css">
    </head>
    <body>
''')
            f.write(formatted_code)
            f.write('''
    </body>
</html>
''')
